<?php

namespace NL\NlMenubuilder\Hooks;

use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Object\ObjectManager;
use TYPO3\CMS\Fluid\View\TemplatePaths;

class ItemsProcFunc
{
    protected $extensionKey = 'nl_menubuilder';

    protected $langPrefix = 'LLL:EXT:nl_menubuilder/Resources/Private/Language/locallang_db.xlf:tx_nlmenubuilder_domain_model_menu.template.I.';

    /**
     * @var ObjectManager
     */
    protected $objectManager;

    /**
     * @var TemplatePaths
     */
    protected $templatePaths;

    /**
     * ItemsProcFunc constructor.
     */
    public function __construct()
    {
        $this->objectManager = GeneralUtility::makeInstance(ObjectManager::class);
        $this->templatePaths = $this->objectManager->get(TemplatePaths::class);
    }

    /**
     * @param array $config
     */
    public function loadMenuGroupTemplates(&$config)
    {
        $this->templatePaths->fillDefaultsByPackageName($this->extensionKey);

        $paths = $this->templatePaths->toArray();

        $templates = [];

        foreach ($paths[TemplatePaths::CONFIG_TEMPLATEROOTPATHS] as $templatePath) {
            $templatePath .= 'ViewHelpers' . DIRECTORY_SEPARATOR . 'Menu'. DIRECTORY_SEPARATOR . 'Render';
            $foundTemplates = GeneralUtility::getFilesInDir($templatePath, 'html');

            $templates = array_merge($templates, $foundTemplates);
        }

        $templates = array_unique($templates);

        foreach ($templates as $template) {
            $template = str_replace('.html', '', $template);
            $config['items'][] = [
                htmlspecialchars($this->getLanguageService()->sL($this->langPrefix . $template)) ?: $template,
                $template
            ];
        }
    }

    /**
     * Returns LanguageService
     *
     * @return mixed
     */
    protected function getLanguageService()
    {
        return $GLOBALS['LANG'];
    }
}
