<?php


namespace NL\NlMenubuilder\Service;


use TYPO3\CMS\Core\Context\AspectInterface;
use TYPO3\CMS\Core\Context\Context;
use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Domain\Model\FrontendUser;
use TYPO3\CMS\Extbase\Domain\Repository\FrontendUserRepository;

class AuthService implements SingletonInterface
{
    /**
     * @var FrontendUserRepository
     */
    protected $userRepository = null;

    /**
     * @param FrontendUserRepository $repository
     */
    public function injectUserRepository(FrontendUserRepository $repository): void
    {
        $this->userRepository = $repository;
    }

    /**
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    public function getUser(): ?FrontendUser
    {
        $id = $this->getPropertyFromAspect('id');

        return $id ? $this->userRepository->findByUid($id) : null;
    }

    /**
     * @return bool
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    public function isLoggedIn(): bool
    {
        return (bool) $this->getPropertyFromAspect('isLoggedIn');
    }

    /**
     * @param string $property
     * @return mixed
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    protected function getPropertyFromAspect(string $property)
    {
        return $this->getAspect()->get($property);
    }

    /**
     * @return object|\Psr\Log\LoggerAwareInterface|SingletonInterface
     */
    protected function getAspect(): AspectInterface
    {
        return GeneralUtility::makeInstance(Context::class)->getAspect('frontend.user');
    }
}
