<?php


namespace NL\NlMenubuilder\Service;


use NL\NlMenubuilder\Domain\Model\MenuInterface;
use NL\NlMenubuilder\Domain\Model\MenuItem;
use NL\NlMenubuilder\Domain\Model\MenuItemPage;
use TYPO3\CMS\Core\SingletonInterface;
use TYPO3\CMS\Core\Utility\GeneralUtility;
use TYPO3\CMS\Extbase\Reflection\ObjectAccess;

class MenuSecurityService implements SingletonInterface
{
    /**
     * @var AuthService
     */
    protected $authService;

    /**
     * @param AuthService $service
     */
    public function injectAuthService(AuthService $service): void
    {
        $this->authService = $service;
    }

    /**
     * @param MenuInterface $menu
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    public function applySecurityCheck(MenuInterface $menu): void
    {
        $this->removeInaccessible($menu);

        $this->removeEmpty($menu);
    }

    /**
     * @param MenuInterface $menu
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    protected function removeInaccessible(MenuInterface $menu): void
    {
        foreach ($menu->getPageItems() as $pageItem) {
            if (false === $this->isAccessible($pageItem)) {
                $menu->removeItem($pageItem);
            }
        }

        foreach ($menu->getSubmenuItems() as $submenuItem) {
            $this->removeInaccessible($submenuItem);
        }
    }

    /**
     * @param MenuInterface $menu
     */
    protected function removeEmpty(MenuInterface $menu): void
    {
        /** @var MenuItem $submenuItem */
        foreach ($menu->getSubmenuItems() as $submenuItem) {
            $this->removeEmpty($submenuItem);

            if (empty($submenuItem->getItems())) {
                $menu->removeItem($submenuItem);
            }
        }
    }

    /**
     * @param MenuItemPage $itemPage
     * @return bool
     * @throws \TYPO3\CMS\Core\Context\Exception\AspectPropertyNotFoundException
     */
    protected function isAccessible(MenuItemPage $itemPage): bool
    {
        $feGroups = array_filter(GeneralUtility::intExplode(
            ',',
            ObjectAccess::getPropertyPath($itemPage, 'page.feGroup'),
            true
        ));

        if (empty($feGroups) || (in_array(-2, $feGroups) && $this->authService->isLoggedIn())) {
            return true;
        }

        if (in_array(-1, $feGroups) && $this->authService->isLoggedIn()) {
            return false;
        }

        if ($user = $this->authService->getUser()) {
            foreach ($user->getUsergroup() as $group) {
                if (in_array($group->getUid(), $feGroups)) {
                    return true;
                }
            }
        }

        return false;
    }
}
